diff graal/GraalCompiler/src/com/sun/c1x/ir/StoreIndexed.java @ 2622:91d3952f7eb7

Framestate work : using stateAFter and reducting the number of nodes with framestates. Intermediate state (does not pass tests)
author Gilles Duboscq <gilles.duboscq@oracle.com>
date Tue, 10 May 2011 12:37:46 +0200
parents 092e628ddd5d
children 569228710be8
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/StoreIndexed.java	Tue May 10 11:55:12 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/StoreIndexed.java	Tue May 10 12:37:46 2011 +0200
@@ -65,11 +65,11 @@
      * @param length the instruction producing the length
      * @param elementType the element type
      * @param value the value to store into the array
      * @param stateBefore the state before executing this instruction
      * @param graph
      */
-    public StoreIndexed(Value array, Value index, Value length, CiKind elementType, Value value, FrameState stateBefore, Graph graph) {
-        super(CiKind.Void, array, index, length, elementType, stateBefore, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public StoreIndexed(Value array, Value index, Value length, CiKind elementType, Value value, FrameState stateAfter, Graph graph) {
+        super(CiKind.Void, array, index, length, elementType, stateAfter, INPUT_COUNT, SUCCESSOR_COUNT, graph);
         setValue(value);
     }
@@ -65,11 +65,11 @@
      * @param elementType the element type
      * @param value the value to store into the array
-     * @param stateBefore the state before executing this instruction
+     * @param stateAfter the state after executing this instruction
      * @param graph
      */